@@ -1,13 +1,15 @@
 //! Unicode to ASCII transliteration
 //!
 //! Converts Unicode characters to their best ASCII representation
-//
-// AnyAscii provides ASCII-only replacement strings for practically all Unicode characters. Text is
-// converted character-by-character without considering the context. The mappings for each script
-// are based on popular existing romanization systems. Symbolic characters are converted based on
-// their meaning or appearance. All ASCII characters in the input are left unchanged, every other
-// character is replaced with printable ASCII characters. Unknown characters and some known
-// characters are replaced with an empty string and removed.
+//!
+//! AnyAscii provides ASCII-only replacement strings for practically all Unicode
+//! characters. Text is converted character-by-character without considering the
+//! context. The mappings for each script are based on popular existing
+//! romanization systems. Symbolic characters are converted based on their
+//! meaning or appearance. All ASCII characters in the input are left unchanged,
+//! every other character is replaced with printable ASCII characters. Unknown
+//! characters and some known characters are replaced with an empty string and
+//! removed.
 //!
 //! This crate supports `no_std` + `alloc`
 
@@ -57,13 +59,7 @@ pub fn any_ascii(s: &str) -> String {
 /// ```
 pub fn any_ascii_char(c: char) -> &'static str {
     let block_num = (c as u32) >> 8;
-    let block_bytes = block::block(block_num);
-    let block: &'static [[u8; 3]] = unsafe {
-        core::slice::from_raw_parts(
-            block_bytes.as_ptr() as *const [u8; 3],
-            block_bytes.len() / 3
-        )
-    };
+    let block = block::block(block_num);
     let lo = (c as u8) as usize;
     if let Some(ptr) = block.get(lo) {
         let l = ptr[2];
@@ -72,7 +68,7 @@ pub fn any_ascii_char(c: char) -> &'static str {
             let ascii_bytes = &ptr[..len];
             unsafe { core::str::from_utf8_unchecked(ascii_bytes) }
         } else {
-            let i = ((u16::from(ptr[0]) << 8) | u16::from(ptr[1])) as usize;
+            let i = u16::from_be_bytes([ptr[0], ptr[1]]) as usize;
             let bank = include_str!("bank.txt");
             unsafe { bank.get_unchecked(i..i + len) }
         }
@@ -94,7 +90,7 @@ fn test() {
     check("\u{0080}", "");
     check("\u{00ff}", "y");
     check("\u{e000}", "");
-    check("\u{fdff}", "");
+    check("\u{ffff}", "");
     check("\u{e0020}", " ");
     check("\u{e007e}", "~");
     check("\u{f0000}", "");
@@ -137,7 +133,7 @@ fn test() {
     check("கன்னியாகுமரி", "knniyakumri");
     check("శ్రీకాకుళం", "srikakulm");
     check("สงขลา", "sngkhla");
-    check("😎 👑 🍎", ":sunglasses: :crown: :apple:");
+    check("👑 🌴", ":crown: :palm_tree:");
     check("☆ ♯ ♰ ⚄ ⛌", "* # + 5 X");
     check("№ ℳ ⅋ ⅍", "No M & A/S");
 
@@ -147,4 +143,14 @@ fn test() {
     check("ⵜⵉⴼⵉⵏⴰⵖ", "tifinagh");
     check("𐍅𐌿𐌻𐍆𐌹𐌻𐌰", "wulfila");
     check("ދިވެހި", "dhivehi");
+    check("ᨅᨔ ᨕᨘᨁᨗ", "bs ugi");
+    check("ϯⲙⲓⲛϩⲱⲣ", "timinhor");
+    check("𐐜 𐐢𐐮𐐻𐑊 𐐝𐐻𐐪𐑉", "Dh Litl Star");
+    check("ꁌꐭꑤ", "pujjytxiep");
+    check("ⰳⰾⰰⰳⱁⰾⰹⱌⰰ", "glagolica");
+    check("ᏎᏉᏯ", "SeQuoYa");
+    check("ㄓㄨㄤ ㄅㄥ ㄒㄧㄠ", "zhuang beng xiao");
+    check("ꚩꚫꛑꚩꚳ ꚳ꛰ꛀꚧꚩꛂ", "ipareim m'shuoiya");
+    check("ᓀᐦᐃᔭᐍᐏᐣ", "nehiyawewin");
+    check("ᠤᠯᠠᠭᠠᠨᠴᠠᠪ", "ulaganqab");
 }
